@@ -325,7 +325,7 @@ class WebSocketController(tornado.websocket.WebSocketHandler, Controller):
         self.dispose_resources()
 
 for method in ["disable_cache", "flash_cookie", "flash_secure_cookie", "load_session"]:
-    setattr(WebSocketController, method, WebSocketController._not_supported)
+    setattr(WebSocketController, method, tornado.websocket._wrap_method(getattr(WebSocketController, method)))
 
 authenticated = tornado.web.authenticated
 
